pub fn on_pre_link(child: impl IntoUiNode, handler: Handler<LinkArgs>) -> UiNode
P Markdown link click.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident